/*
 *  oftc-services: irc services for the OFTC network
 *  channels.h - channel management
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: channel.h 100 2003-11-05 00:33:42Z stu $
 */

#ifndef CHANNELS_H_INCLUDED
#define CHANNELS_H_INCLUDED

#define CMODE_ADD 1
#define CMODE_DEL 2

#define CMODE_INVITE        0x000001
#define CMODE_MODERATED     0x000002
#define CMODE_NOEXTERNALMSG 0x000004
#define CMODE_PRIVATE       0x000008
#define CMODE_SECRET        0x000010
#define CMODE_TOPICOPS      0x000020
#define CMODE_KEY           0x000040
#define CMODE_NOCOLOURS     0x000080
#define CMODE_LIMIT         0x000100

#define SetInviteOnly(x)    ((x)->mode |= CMODE_INVITE)
#define SetModerated(x)     ((x)->mode |= CMODE_MODERATED)
#define SetNoMsgs(x)        ((x)->mode |= CMODE_NOEXTERNALMSG)
#define SetPrivate(x)       ((x)->mode |= CMODE_PRIVATE)
#define SetSecret(x)        ((x)->mode |= CMODE_SECRET)
#define SetTopicOps(x)      ((x)->mode |= CMODE_TOPICOPS)
#define SetKeyed(x)         ((x)->mode |= CMODE_KEY)
#define SetNoColours(x)     ((x)->mode |= CMODE_COLOURS)
#define SetLimited(x)       ((x)->mode |= CMODE_LIMIT)
 
#define IsInviteOnly(x)     ((x)->mode & CMODE_INVITE)
#define IsModerated(x)      ((x)->mode & CMODE_MODERATED)
#define IsNoMsgs(x)         ((x)->mode & CMODE_NOEXTERNALMSG)
#define IsPrivate(x)        ((x)->mode & CMODE_PRIVATE)
#define IsSecret(x)         ((x)->mode & CMODE_SECRET)
#define IsTopicOps(x)       ((x)->mode & CMODE_TOPICOPS)
#define IsKeyed(x)          ((x)->mode & CMODE_KEY)
#define IsNoColours(x)      ((x)->mode & CMODE_NOCOLOURS)
#define IsLimited(x)        ((x)->mode & CMODE_LIMIT)

#define ClearInviteOnly(x)  ((x)->mode &= ~CMODE_INVITE)
#define ClearModerated(x)   ((x)->mode &= ~CMODE_MODERATED)
#define ClearNoMsgs(x)      ((x)->mode &= ~CMODE_NOEXTERNALMSG)
#define ClearPrivate(x)     ((x)->mode &= ~CMODE_PRIVATE)
#define ClearSecret(x)      ((x)->mode &= ~CMODE_SECRET)
#define ClearTopicOps(x)    ((x)->mode &= ~CMODE_TOPICOPS)
#define ClearKeyed(x)       ((x)->mode &= ~CMODE_KEY)
#define ClearNoColours(x)   ((x)->mode &= ~CMODE_COLOURS)
#define ClearLimited(x)     ((x)->mode &= ~CMODE_LIMIT)

struct User;

extern void get_channel_stats(long *, long *);
extern struct Channel *findchan(const char *);
extern struct Channel *findchan_by_id(unsigned int);

extern void chan_adduser(struct User *, const char *);
extern void chan_deluser(struct User *, struct Channel *);

extern void do_cmode(const char *, int, char **);
extern void do_topic(const char *, int, char **);

extern int only_one_user(const char *);

extern void chan_update_events(time_t);
extern unsigned int chan_count_regex_match(regex_t *);
extern void check_autolimit(struct Channel *, time_t, int);

struct Ban
{
    char *mask;
    time_t time;
};

struct Channel
{
    dlink_node node;
    char name[CHANLEN];
    unsigned int channel_id;
    time_t creation_time;
    char topic[TOPICLEN];
    char topic_setter[NICKLEN];
    time_t topic_time;
    unsigned int mode;
    unsigned int limit;
    char *key;
    size_t bancount;
    size_t bansize;
    struct Ban **newbans;
    dlink_list users, chanops, voices;
    time_t server_modetime;
    time_t chanserv_modetime;
    int server_modecount;
    int chanserv_modecount;
    int bouncy_modes;
    time_t last_limit_time;
    unsigned int limit_offset;
    unsigned int limit_tolerance;
    unsigned int limit_period;
    unsigned int bantime;
    int floodserv;
    struct Channel *hnext;
};

struct mode_letter
{
    const unsigned int mode;
    const unsigned char letter;
};


#endif
