/*
 *  oftc-services: irc services for the OFTC network
 *  chanserv.h - structures and defines relating to chanserv
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: chanserv.h 100 2003-11-05 00:33:42Z stu $
 */

#ifndef CHANNEL_H_INCLUDED
#define CHANNEL_H_INCLUDED

#define CA_INVITE           0
#define CA_AKICK            1
#define CA_SET              2
#define CA_UNBAN            3
#define CA_AUTOOP           4
#define CA_AUTODEOP         5
#define CA_AUTOVOICE        6
#define CA_OPDEOP           7
#define CA_ACCESS_LIST      8
#define CA_CLEAR            9
#define CA_NOJOIN           10
#define CA_ACCESS_CHANGE    11
#define CA_MEMO_READ        12
#define CA_LEVEL_LIST       13
#define CA_LEVEL_CHANGE     14
#define CA_SYNC             15
#define CA_MEMO_SEND        16
#define CA_AKICK_LIST       17
#define CA_SIZE             18

#define CI_KEEPTOPIC    0x00000001
#define CI_SECUREOPS    0x00000002
#define CI_PRIVATE  0x00000004
#define CI_TOPICLOCK    0x00000008
#define CI_RESTRICTED   0x00000010
#define CI_LEAVEOPS 0x00000020
#define CI_SECURE   0x00000040
#define CI_VERBOTEN 0x00000080
#define CI_NO_EXPIRE    0x00000200
#define CI_MEMO_HARDMAX 0x00000400
#define CI_VERBOSE  0x00000800

#define ACCESS_FOUNDER	10000
#define ACCESS_INVALID	-10000

struct ChanAccess
{
    unsigned int chanaccess_id;
    unsigned int channel_id;
    unsigned int idx;
    int level;
    unsigned int nick_id;
    time_t added;
    time_t last_modified;
    time_t last_used;
    time_t memo_read;
    char added_by[NICKLEN];
    char modified_by[NICKLEN];
};

struct ChannelInfo {
    unsigned int channel_id;
    char name[CHANMAX];
    unsigned int founder;
    unsigned int successor;
    char founderpass[PASSMAX];
    char salt[SALTMAX];
    char *desc;
    char *url;
    char *email;
    time_t time_registered;
    time_t last_used;
    time_t founder_memo_read;
    char *last_topic;
    char last_topic_setter[NICKMAX];
    time_t last_topic_time;
    int flags;
    int mlock_on;
    int mlock_off;
    unsigned int mlock_limit;
    char *mlock_key;
    char *entry_message;
    time_t last_limit_time;
    unsigned int limit_offset;
    unsigned int limit_tolerance;
    unsigned int limit_period;
    unsigned int bantime;
    char last_sendpass_pass[PASSMAX];
    char last_sendpass_salt[SALTMAX];
    time_t last_sendpass_time;
    int floodserv;
    dlink_node node;
};


struct User;
struct Channel;
struct MemoInfo;

extern void listchans(int, const char *);
extern void get_chanserv_stats(long *, long *);
extern void cs_init(void);
extern void chanserv(const char *, char *);
extern void load_cs_dbase(void);
extern void save_cs_dbase(void);
extern void check_modes(const char *);
extern int check_valid_op(struct User *, const char *, int);
extern int check_should_op(struct User *, const char *);
extern int check_should_voice(struct User *, const char *);
extern void check_chan_memos(struct User *, unsigned int);
extern int check_kick(struct User *user, const char *chan);
extern void record_topic(const char *);
extern void restore_topic(const char *);
extern int check_topiclock(const char *, const char *, struct Channel *);
extern void expire_chans(void);
extern void cs_mysql_remove_nick(unsigned int);
extern struct ChannelInfo *cs_findchan(const char *);
extern int check_access(struct User *user, unsigned int, int);
extern int check_chan_limit(unsigned int);
extern void update_memo_time(struct User *, const char *, time_t);
extern void get_chan_name(unsigned int, char *);
extern unsigned int mysql_findchan(const char *);
extern char *get_channame_from_id(unsigned int);
extern void add_mlock_on(unsigned int, int);
extern void remove_mlock_off(unsigned int, int);
extern char *get_entrymsg(unsigned int);
extern int get_chan_flags(unsigned int);
extern int get_channelinfo_from_id(struct ChannelInfo *, unsigned int);
extern void free_channelinfo(struct ChannelInfo *);
extern void add_chan_flags(unsigned int, int);
extern void remove_chan_flags(unsigned int, int);
extern int get_access(struct User *, unsigned int);
extern int get_chanaccess_from_nickid(struct ChanAccess *, unsigned int, unsigned int);
extern void free_chanaccess(struct ChanAccess *);
extern int get_level(unsigned int, int);
extern int get_chan_level(unsigned int, int);

extern void do_cs_access(struct User *);
extern void do_cs_vop(struct User *);
extern void do_cs_aop(struct User *);
extern void do_cs_sop(struct User *);

#endif
