/*
 *  oftc-services: irc services for the OFTC network
 *  nickserv.h - structures and defines relating to nickserv
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: nickserv.h 100 2003-11-05 00:33:42Z stu $
 */

#ifndef NICKSERV_H_INCLUDED
#define NICKSERV_H_INCLUDED

#define NS_VERBOTEN     0x0002
#define NS_NO_EXPIRE    0x0004
#define NS_GUESTED      0x0100
#define NS_REGAINED     0x0200
#define NS_KILL_HELD    0x1000
#define NS_ON_ACCESS    0x2000
#define NS_RECOGNIZED   0x4000
#define NS_IDENTIFIED   0x8000
#define NS_TEMPORARY    0xFF00

#define NI_ENFORCE      0x00000001
#define NI_SECURE       0x00000002
#define NI_MEMO_HARDMAX 0x00000008
#define NI_MEMO_SIGNON  0x00000010
#define NI_MEMO_RECEIVE 0x00000020
#define NI_PRIVATE      0x00000040
#define NI_HIDE_EMAIL   0x00000080
#define NI_HIDE_MASK    0x00000100
#define NI_HIDE_QUIT    0x00000200
#define NI_ENFORCEQUICK 0x00000400
#define NI_NOOP         0x00000800
#define NI_IRCOP        0x00001000
#define NI_MARKED       0x00002000
#define NI_NOSENDPASS   0x00004000
#define NI_AUTOJOIN     0x00008000
#define NI_CLOAK        0x00010000
#define NI_SUSPENDED    0x10000000

struct NickInfo 
{
	unsigned int nick_id;
	char nick[NICKLEN];
	char pass[PASSLEN];
	char salt[SALTLEN];
	char *url;
	char *email;
	char *last_usermask;
	char *last_realname;
	char *last_quit;
	time_t last_quit_time;
	time_t time_registered;
	time_t last_seen;
	int status;
    unsigned int link_id;
    unsigned int channelmax;
    int flags;
    unsigned int language;
    time_t id_stamp;                                            
                                                                
    int regainid;
    char last_sendpass_pass[PASSMAX];
    char last_sendpass_salt[SALTMAX];
    time_t last_sendpass_time;

};

struct User;

extern struct NickInfo *nicklists[256];

extern void ns_init(void);
extern void listnicks(int, const char *);
extern void get_nickserv_stats(long *, long *);
extern void nickserv(const char *, char *);
extern void load_ns_dbase(void);
extern void save_ns_dbase(void);
extern int check_on_access(struct User *);
extern int validate_user(struct User *);
extern void cancel_user(struct User *);
extern int nick_identified(struct User *);
extern int nick_recognized(struct User *);
extern void expire_nicksuspends(void);
extern void expire_nicks(void);
extern void set_nick_status(unsigned int, int);
extern int get_nick_status(unsigned int);
extern struct NickInfo *findnick(const char *);
extern struct NickInfo *getlink(struct NickInfo *);
extern unsigned int get_nickinfo_from_id(struct NickInfo *, unsigned int);
extern void free_nickinfo(struct NickInfo *);
extern char *get_nick_from_id(unsigned int);
extern char *get_email_from_id(unsigned int);
extern char *get_cloak_from_id(unsigned int);
extern int get_nick_flags(unsigned int);
extern void add_nick_flags(unsigned int, int);
extern void remove_nick_flags(unsigned int, int);
extern void mysql_update_last_seen(struct User *, int);

extern void do_autojoin(struct User *);
extern void check_autojoins(struct User *);
extern void renumber_autojoins(unsigned int);

#endif
