/*! \file services.h 
 *  \brief Main header for Services.
 */

/*
 * Blitzed Services copyright (c) 2000-2001 Blitzed Services team
 *     E-mail: services@lists.blitzed.org
 * Based on ircservices-4.4.8:
 * copyright (c) 1996-1999 Andrew Church
 *     E-mail: <achurch@dragonfire.net>
 * copyright (c) 1999-2000 Andrew Kempe.
 *     E-mail: <theshadow@shadowfire.org>
 *
 * This program is free but copyrighted software; see the file COPYING for
 * details.
 *
 * $Id: services.h 100 2003-11-05 00:33:42Z stu $
 */

#ifndef SERVICES_H
#define SERVICES_H

void kill_user(const char *, const char *, const char *);
void bad_password(struct User *);

extern int nofork;
extern char *etcdir;
extern char *services_dir;
extern char *log_filename;
extern int   skeleton;
extern int   forceload;

extern int   quitting;
extern int   delayed_quit;
extern char *quitmsg;
extern char  inbuf[BUFSIZE];
extern int   servsock;
extern int   save_data;
extern int   got_alarm;
extern volatile time_t last_update;
extern volatile time_t last_chanevent;
extern sigjmp_buf panic_jmp;

#if CHANNEL_MAXREG > 32767
# undef CHANNEL_MAXREG
# define CHANNEL_MAXREG	0
#endif
#if DEF_MAX_MEMOS > 32767
# undef DEF_MAX_MEMOS
# define DEF_MAX_MEMOS	0
#endif
#if MAX_SERVOPERS > 32767
# undef MAX_SERVOPERS
# define MAX_SERVOPERS 32767
#endif
#if MAX_SERVADMINS > 32767
# undef MAX_SERVADMINS
# define MAX_SERVADMINS 32767
#endif

typedef struct memo_ Memo;

/*!
 * \brief Memo data structures.
 *
 * Since both nicknames and channels can have memos, we encapsulate memo data
 * in a generic Memo structure to make it easier to handle.
 */

struct memo_ {
	/*! \brief Unique memo identifier. */
	unsigned int memo_id;
	
	/*! \brief Index within the user's memos. */
	unsigned int idx;
	
	/*! \brief Flags for memo metadata. */
	int flags;
	
	/*!
	 * \brief String identifying owner of this memo (nick or
	 * channel).
	 */
	char *owner;
	
	/*! \brief When the memo was sent. */
	time_t time;
	
	/*! \brief Nick of memo sender. */
	char sender[NICKMAX];
	
	/*! \brief Memo content. */
	char *text;
};

#define MF_UNREAD	0x0001
#define MF_GLOBALSEND	0x0002
#define MF_OPERSEND	0x0004
#define MF_CSOPSEND	0x0008

typedef struct channellist_ ChannelList;

/*! \brief Nickname info structure. */

#define ACCESS_FOUNDER	10000
#define ACCESS_INVALID	-10000

/*!
 * \brief AutoKick data.
 *
 * All AutoKick data is stored in the akick table in MySQL.
 */
typedef struct {
	/*! \brief Unique identifier for each AutoKick. */
	unsigned int akick_id;
	
	/*! \brief Channel to which this AutoKick belongs. */
	unsigned int channel_id;
	
	/*! \brief Index used to order each channel's AutoKicks. */
	unsigned int idx;
	
	/*!
	 * \brief Hostmask to be affected by the AutoKick.
	 *
	 * If the AutoKick is placed on a hostmask then \link
	 * AutoKick::nick_id nick_id \endlink will be zero.  Otherwise, if
	 * the AutoKick is for a specific registered nick, then this member
	 * will be NULL.
	 */
	char *mask;
	
	/*!
	 * \brief ID of the nick to be affected by this AutoKick.
	 *
	 * If the AutoKick is placed on a specific registered nick then its
	 * \link NickInfo::nick_id nick_id \endlink will be stored here.
	 * Otherwise, this member will be 0.
	 */
	unsigned int nick_id;
	
	/*! \brief Reason for the AutoKick. */
	char *reason;
	
	/*! \brief Nickname of the user who added this AutoKick. */
	char who[NICKMAX];
	
	/*! \brief Time that this AutoKick was added. */
	time_t added;
	
	/*! \brief Time that this AutoKick was last matched. */
	time_t last_used;
} AutoKick;

/* Suspension info structures. */

typedef struct suspendinfo_ SuspendInfo;

/*!
 * \brief Suspension info structure.
 *
 * Since both nicks and channels can be suspended, this structure holds the
 * generic suspension details that apply to both.
 */
struct suspendinfo_ {
	/*! \brief Unique identifier for this suspend. */
	unsigned int suspend_id;
	
	/*! \brief Nick of the person who set this suspension. */
	char who[NICKMAX];
	
	/*! \brief Reason for suspension. */
	char *reason;
	
	/*! \brief Time that entity was suspended. */
	time_t suspended;
	
	/*!
	 * \brief When the suspension will expire.
	 *
	 * 0 indicates a permanent suspension.
	 */
	time_t expires;		/* 0 for no expiry */
};

typedef struct suspendednick_ NickSuspend;

/*! \brief Suspended nick info. */
struct suspendednick_ {
	/*! \brief Unique identifier for this nick suspension. */
	unsigned int nicksuspend_id;
	
	/*!
	 * \brief \link NickInfo::nick_id nick_id \endlink of the nick
	 * which is being suspended.
	 */
	unsigned int nick_id;
	
	/*!
	 * \brief \link SuspendInfo::suspend_id suspend_id \endlink which
	 * identifies the corresponding SuspendInfo structure.
	 */
	unsigned int suspend_id;
};

typedef struct suspendedchan_ ChanSuspend;

/*! \brief Suspended channel info. */
struct suspendedchan_ {
	/*! \brief Unique identifier for this channel suspension. */
	unsigned int chansuspend_id;
	
	/*!
	 * \brief \link ChannelInfo::channel_id channel_id \endlink of the
	 * channel which is being suspended.
	 */
	unsigned int channel_id;
	
	/*!
	 * \brief \link SuspendInfo::suspend_id suspend_id \endlink which
	 * identifies the corresponding SuspendInfo structure.
	 */
	unsigned int suspend_id;
};

/*************************************************************************/

typedef struct serverstats_ ServerStats;

struct minmax_ {
	/*! \brief min/max values. */
	int min, max;

	/*! \brief Time that the min or max was recorded. */
	time_t mintime, maxtime;
};

/*************************************************************************/

/*! \name News Types */

/* @{ */

/*! \brief General logon news shown to all clients. */
#define NEWS_LOGON	0

/*! \brief Oper news - shown after a client opers up. */
#define NEWS_OPER	1

/* @} */

/*!
 * \brief SHA1 data.
 *
 * I have no idea how this works as I just ripped it out of gnupg
 * (http://www.gnupg.org) <tt>:-)</tt>
 */
typedef struct {
	uint32 h0, h1, h2, h3, h4;
	uint32 nblocks;
	unsigned char buf[64];
	int count;
} SHA1_CONTEXT;


#endif				/* SERVICES_H */
