/*
 *  oftc-services: irc services for the OFTC network
 *  mysql.h - structures and defines relating to MySQL
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: smysql.h 100 2003-11-05 00:33:42Z stu $
 */

#ifndef MYSQL_H_INC
#define MYSQL_H_INC

struct NickInfo;
struct User;

extern int log_sql;

extern MYSQL mysql;
extern MYSQL *mysqlconn;

extern void smysql_init(void);
extern void handle_mysql_error(MYSQL *mysql, const char *msg);
extern MYSQL_RES *smysql_bulk_query(MYSQL *mysql, unsigned int *num_fields,
                   unsigned int *num_rows, const char *fmt, ...);
extern MYSQL_RES *mysql_simple_query(MYSQL *mysql, unsigned int *err,
                const char *fmt, ...);
extern MYSQL_RES *smysql_query(MYSQL *mysql, const char *fmt, ...);
extern MYSQL_ROW smysql_fetch_row(MYSQL *mysql, MYSQL_RES *result);
extern void get_table_stats(MYSQL *mysql, const char *table,
               unsigned int *nrec, unsigned int *bytes);
extern unsigned int get_table_rows(MYSQL *mysql, const char *table);
extern unsigned int count_matching_rows(MYSQL *mysql, const char *table,
                           const char *column, const char *string);
extern void read_lock_table(MYSQL *mysql, const char *table);
extern void write_lock_table(MYSQL *mysql, const char *table);
extern void unlock(MYSQL *mysql);
extern void smysql_cleanup(MYSQL *mysql);
extern int check_chunk(int i, size_t *size, char *chunk);
extern char *mysql_build_query(MYSQL *mysql, const char *numstr,
              const char *base, const char *column,
              unsigned int max);
extern char *mysql_build_query_match_mask(MYSQL *mysql, const char *mask,
                     const char *base, const char *table,
                     const char *id_col, const char *mask_col);
extern char *smysql_escape_string(MYSQL *mysql, const char *string);
extern void smysql_log(const char *fmt, ...);
extern int open_mysql_log(void);
extern void close_mysql_log(void);

extern unsigned int mysql_findnick(const char *nick);
extern unsigned int mysql_findnickinfo(struct NickInfo *ni, const char *nick);
extern unsigned int mysql_getlink(unsigned int nick_id);

#endif
