/*
 *  oftc-services: irc services for the OFTC network
 *  user.h - structures and defines relating to users
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: user.h 100 2003-11-05 00:33:42Z stu $
 */

#ifndef USER_H_INCLUDED
#define USER_H_INCLUDED

struct Channel;

struct User
{
    dlink_node unode; /* list node for the user list */
    dlink_node cnode; /* list node for channel lists */
    dlink_node chnode; /* list node for channels users is on */
    char nick[NICKLEN];
    char username[USERLEN];
    char host[HOSTLEN];
    char realname[REALLEN];
    struct Server *server;  /* User's server */
    struct User *hnext;     /* Next bucket in the hash */
    unsigned int nick_id;   /* master nick id */
    unsigned int real_id;   /* nick id */
    unsigned int mode;      /* Usermode */
    time_t signon;          /* TS server side */
    time_t my_signon;       /* TS that we first saw this user */
    dlink_list chans;       /* Channels user is on */
    dlink_list founder_chans; /* Channels this user is founder of */
    short invalid_pw_count; /* Number of invalid password attempts */
    time_t invalid_pw_time; /* Time of last password attempt */
    time_t lastmemosend;    /* Last time memoserv SEND issued */
    time_t lastnickreg;     /* Last time nickserv REGISTER issued */
};

extern dlink_list user_list;
extern u_int32_t usercnt, opcnt, maxusercnt;
extern time_t maxusertime; 

/* User modes available */

#define UMODE_OPER          0x000001
#define UMODE_INVISIBLE     0x000002
#define UMODE_WALLOPS       0x000004
#define UMODE_NICKSERVREG   0x000008
#define UMODE_GLOBAL        0x000010
#define UMODE_SERVNOTE      0x000020
#define UMODE_GOD           0x000040

#define IsOper(x)           ((x)->mode & UMODE_OPER)
#define IsNickReg(x)        ((x)->mode & UMODE_NICKSERVREG)

#define SetOper(x)          ((x)->mode |= UMODE_OPER)
#define SetNickReg(x)       ((x)->mode |= UMODE_NICKSERVREG)

#define ClearOper(x)        ((x)->mode &= ~UMODE_OPER)
#define ClearNickReg(x)     ((x)->mode &= ~UMODE_NICKSERVREG)

extern int  do_nick(const char *, int, char **);
extern void do_join(const char *, int, char **);
extern void do_sjoin(const char *, int, char **);
extern void do_part(const char *, int, char **);
extern void do_kick(const char *, int, char **);
extern void do_umode(const char *, int, char **);
extern void do_quit(const char *, int, char **);
extern void do_kill(const char *, int, char **);
extern int  is_services_oper(struct User *);
extern int  is_services_root(struct User *);
extern int  is_services_admin(struct User *);
extern int  nick_is_services_admin(unsigned int);
extern void get_user_stats(long *, long *);
extern struct User *finduser(const char *);

extern int is_oper(const char *);
extern int is_on_chan(const char *, const char *);
extern int is_chanop(const char *, const char *);
extern int is_voiced(const char *, const char *);
extern int is_banned(struct User *, struct Channel *);

extern int match_usermask(const char *, struct User *);
extern int count_mask_matches(const char *);
extern void split_usermask(const char *, char **, char **, char **);
extern char *create_mask(struct User *);
extern unsigned int chan_count_users(struct Channel *);

#endif
