/*
 *  oftc-services: irc services for the OFTC network
 *  actions.c - various routines to perform simple actions
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: actions.c 100 2003-11-05 00:33:42Z stu $

 * original copyright follows: 
 *
 * Blitzed Services copyright (c) 2000-2002 Blitzed Services team
 *     E-mail: services@lists.blitzed.org
 * Based on ircservices-4.4.8:
 * copyright (c) 1996-1999 Andrew Church.
 *     E-mail: <achurch@dragonfire.net>
 * copyright (c) 1999-2000 Andrew Kempe.
 *     E-mail: <theshadow@shadowfire.org>
 *     
 */

#include "stdinc.h"
#include "tools.h"
#include "user.h"
#include "channel.h"
#include "send.h"
#include "akill.h"
/*************************************************************************/

/* Remove a user from the IRC network.  `source' is the nick which should
 * generate the kill, or NULL for a server-generated kill.
 */

void 
kill_user(const char *source, const char *user, const char *reason)
{
    char *av[2];
    char buf[BUFSIZE];

    if (EmptyString(user))
    	return;
    if (EmptyString(source))
        source = ServerName;
    snprintf(buf, sizeof(buf), "%s (%s)", source, reason ? reason : "");
    av[0] = (char *)user;
    av[1] = buf;
    send_cmd(source, "KILL %s :%s", user, av[1]);
    do_kill(source, 2, av);
}

/*************************************************************************/

/* Note a bad password attempt for the given user.  If they've used up
 * their limit, toss them off.
 */

void
bad_password(struct User *user)
{
    time_t now = time(NULL);

    if (!BadPassLimit)
        return;

    if (BadPassTimeout > 0 && user->invalid_pw_time > 0 && 
            user->invalid_pw_time < now - BadPassTimeout)
        user->invalid_pw_count = 0;
    user->invalid_pw_count++;
    user->invalid_pw_time = now;
    if (user->invalid_pw_count >= BadPassLimit)
        kill_user(NULL, user->nick, "Too many invalid passwords");
}

/*************************************************************************/
