/*
 *  oftc-services: irc services for the OFTC network
 *  auth.c - routines relating to the auth system
 *
 *  Copyright (C) 2003 Stuart Walsh
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 *  USA
 *
 *  $Id: auth.c 100 2003-11-05 00:33:42Z stu $

 *
 * original copyright (c) 2000-2002 Blitzed Services team
 *     E-mail: services@lists.blitzed.org
 */

#include <stdlib.h>
#include <time.h>

#include "stdinc.h"
#include "smysql.h"
#include "log.h"
#define SECS_24_HRS 86400

/*
 * expire_auth: arrange for rows in the auth table to be correctly expired.
 * Currently this means any rows older than 24 hours.
 */
void 
expire_auth(time_t now)
{
    char tbuf[100];
    MYSQL_ROW row;
    MYSQL_RES *result;
    unsigned int fields, rows;
    time_t created;
    struct tm *tp;

    write_lock_table(mysqlconn, "auth");

    if (debug) 
    {
        result = smysql_bulk_query(mysqlconn, &fields, &rows,
                "SELECT name, command, create_time FROM auth "
                "WHERE (create_time + %u) < %lu", SECS_24_HRS, now);
        while ((row = smysql_fetch_row(mysqlconn, result))) 
        {
            created = atoi(row[2]);
            tp = gmtime(&created);
            strftime(tbuf, sizeof(tbuf), "%d/%b/%Y %H:%M:%S", tp);
            slog("auth_expire: Expiring command %s by %s created %s", 
                    row[1], row[0], tbuf);
            snoop(s_OperServ, "[AUTH] Expiring command %s by %s created %s",
                    row[1], row[0], tbuf);
        }
        mysql_free_result(result);
    }
    result = smysql_bulk_query(mysqlconn, &fields, &rows,
            "DELETE FROM auth WHERE (create_time + %u) < %lu", SECS_24_HRS, 
            now);
    mysql_free_result(result);

    unlock(mysqlconn);
    return;
}
