/* Memory management routines.
 *
 * Services is copyright (c) 1996-1999 Andrew Church.
 *     E-mail: <achurch@dragonfire.net>
 * Services is copyright (c) 1999-2000 Andrew Kempe.
 *     E-mail: <theshadow@shadowfire.org>
 * This program is free but copyrighted software; see the file COPYING for
 * details.
 */

#include "stdinc.h"
#include "tools.h"
#include "user.h"
#include "services.h"
#include "log.h"

/* $Id: memory.c 100 2003-11-05 00:33:42Z stu $ */

/*************************************************************************/
/*************************************************************************/

/* smalloc, scalloc, srealloc, sstrdup:
 *	Versions of the memory allocation functions which will cause the
 *	program to terminate with an "Out of memory" error if the memory
 *	cannot be allocated.  (Hence, the return value from these functions
 *	is never NULL.)
 */

void *
smalloc(size_t size)
{
    void *buf;

    if (!size) 
    {
	    slog("smalloc: Illegal attempt to allocate 0 bytes");
	    size = 1;
    }
    buf = calloc(size, 1);
    if (buf == NULL)
	    raise(SIGUSR1);
    return buf;
}

void *scalloc(size_t elsize, size_t els)
{
    void *buf;

    if (!elsize || !els) {
	slog("scalloc: Illegal attempt to allocate 0 bytes");
	elsize = els = 1;
    }
    buf = calloc(elsize, els);
    if (!buf)
	raise(SIGUSR1);
    return buf;
}

void *srealloc(void *oldptr, size_t newsize)
{
    void *buf;

    if (!newsize) {
	slog("srealloc: Illegal attempt to allocate 0 bytes");
	newsize = 1;
    }
    buf = realloc(oldptr, newsize);
    if (!buf)
	raise(SIGUSR1);
    return buf;
}

char *sstrdup(const char *s)
{
    char *t = strdup(s);
    if (!t)
	raise(SIGUSR1);
    return t;
}

void
sfree(void *ptr)
{
    if(ptr)
        free(ptr);
}
/*************************************************************************/
/*************************************************************************/

/* In the future: malloc() replacements that tell us if we're leaking and
 * maybe do sanity checks too... */

/*************************************************************************/
